==> currents-api-types-0.0.42.tgz: package/graph/strategy/parsers.ts <==
import z from 'zod';
import { ROUTING_STRATEGIES, ROUTING_STRATEGY_KEY_FANOUT, ROUTING_STRATEGY_KEY_THRESHOLD } from './constants';
import { Subset } from '../../utils/types';
import { makePositiveIntegerQueryParser } from '../../common/parsers/queryParams';
import { DEFAULT_ROUTING_STRATEGY } from './defaults';

export const routingStrategyFanoutKeyParser = z.literal(ROUTING_STRATEGY_KEY_FANOUT);
export const routingStrategyThresholdKeyParser = z.literal(ROUTING_STRATEGY_KEY_THRESHOLD);
export const routingStrategyKeyParser = routingStrategyFanoutKeyParser.or(routingStrategyThresholdKeyParser);
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertStrategies1 = Subset<typeof ROUTING_STRATEGIES[number], z.infer<typeof routingStrategyKeyParser>>;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertStrategies2 = Subset<z.infer<typeof routingStrategyKeyParser>, typeof ROUTING_STRATEGIES[number]>;
export const routingStrategyFanoutParser = z.object({
  key: routingStrategyFanoutKeyParser,
});
export const routingStrategyFanoutQueryParser = z.object({
  key: routingStrategyFanoutKeyParser,
});
export const routingStrategyThresholdQueryParamsParser = z.object({
  threshold: makePositiveIntegerQueryParser('Threshold'),
});
export const routingStrategyThresholdParser = z.object({
  key: routingStrategyThresholdKeyParser,
  params: z.object({
    threshold: z.number(),
  }),
});
export const routingStrategyThresholdQueryParser = z.object({
  key: routingStrategyThresholdKeyParser,
  params: routingStrategyThresholdQueryParamsParser,
});
export const routingStrategyParser = z.discriminatedUnion('key', [
  routingStrategyFanoutParser,
  routingStrategyThresholdParser,
]);

// doesn't work well with a flat object
// export const routingStrategyQueryParser = z.discriminatedUnion('strategy', [
//   routingStrategyFanoutQueryParser,
//   routingStrategyThresholdQueryParser,
// ]);

// nested
export const routingStrategyQueryParser = z.object({
  strategy: z
    .discriminatedUnion('key', [routingStrategyFanoutQueryParser, routingStrategyThresholdQueryParser])
    .default(DEFAULT_ROUTING_STRATEGY),
});

==> currents-api-types-0.0.51.tgz: package/graph/strategy/parsers.ts <==
import z from 'zod';
import {
  ROUTING_STRATEGIES,
  ROUTING_STRATEGY_KEY_ACTIVATION_THRESHOLD,
  ROUTING_STRATEGY_KEY_FANOUT,
  ROUTING_STRATEGY_KEY_THRESHOLD,
} from './constants';
import { Subset } from '../../utils/types';
import { makePositiveIntegerQueryParser } from '../../common/parsers/queryParams';
import { DEFAULT_ROUTING_STRATEGY } from './defaults';

export const routingStrategyFanoutKeyParser = z.literal(ROUTING_STRATEGY_KEY_FANOUT);
export const routingStrategyThresholdKeyParser = z.literal(ROUTING_STRATEGY_KEY_THRESHOLD);
export const routingStrategyActivationThresholdKeyParser = z.literal(ROUTING_STRATEGY_KEY_ACTIVATION_THRESHOLD);
export const routingStrategyKeyParser = routingStrategyFanoutKeyParser
  .or(routingStrategyThresholdKeyParser)
  .or(routingStrategyActivationThresholdKeyParser);
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertStrategies1 = Subset<typeof ROUTING_STRATEGIES[number], z.infer<typeof routingStrategyKeyParser>>;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertStrategies2 = Subset<z.infer<typeof routingStrategyKeyParser>, typeof ROUTING_STRATEGIES[number]>;
export const routingStrategyFanoutParser = z.object({
  key: routingStrategyFanoutKeyParser,
});
export const routingStrategyFanoutQueryParser = z.object({
  key: routingStrategyFanoutKeyParser,
});
export const routingStrategyThresholdQueryParamsParser = z.object({
  threshold: makePositiveIntegerQueryParser('Threshold'),
});
export const routingStrategyThresholdParser = z.object({
  key: routingStrategyThresholdKeyParser,
  params: z.object({
    threshold: z.number(),
  }),
});

export const routingStrategyActivationThresholdParser = z.object({
  key: routingStrategyActivationThresholdKeyParser,
  // activation value depends on the property on the node
  // params: z.object({
  //   threshold: z.number(),
  // })
});

export const routingStrategyThresholdQueryParser = z.object({
  key: routingStrategyThresholdKeyParser,
  params: routingStrategyThresholdQueryParamsParser,
});
export const routingStrategyParser = z.discriminatedUnion('key', [
  routingStrategyFanoutParser,
  routingStrategyThresholdParser,
  routingStrategyActivationThresholdParser,
]);

// doesn't work well with a flat object
// export const routingStrategyQueryParser = z.discriminatedUnion('strategy', [
//   routingStrategyFanoutQueryParser,
//   routingStrategyThresholdQueryParser,
// ]);

// nested
export const routingStrategyQueryParser = z.object({
  strategy: z
    .discriminatedUnion('key', [routingStrategyFanoutQueryParser, routingStrategyThresholdQueryParser])
    .default(DEFAULT_ROUTING_STRATEGY),
});
